
# chipmunkdb :chipmunk: python-client

Modify and save dataframes with timeseries or without to an ultra-fast ipc chipmunk database with olap features. (Powered by duckdb)

## Installation


## Usage

## Info
